You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by ma...@apache.org on 2013/08/01 18:38:14 UTC

svn commit: r1509322 - in /commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl: GenericKeyedObjectPool.java GenericKeyedObjectPoolMXBean.java GenericObjectPool.java

Author: markt
Date: Thu Aug  1 16:38:13 2013
New Revision: 1509322

URL: http://svn.apache.org/r1509322
Log:
Javadoc fixes

Modified:
    commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPool.java
    commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPoolMXBean.java
    commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericObjectPool.java

Modified: commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPool.java
URL: http://svn.apache.org/viewvc/commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPool.java?rev=1509322&r1=1509321&r2=1509322&view=diff
==============================================================================
--- commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPoolMXBean.java (original)
+++ commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPoolMXBean.java Thu Aug  1 16:38:13 2013
@@ -146,7 +146,7 @@ public interface GenericKeyedObjectPoolM
      */
     int getNumWaiters();
     /**
-     * See {@link GenericKeyedObjectPool#getNumWaiters(Object)}
+     * See {@link GenericKeyedObjectPool#getNumWaitersByKey()}
      */
     Map<String,Integer> getNumWaitersByKey();
     /**

Modified: commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericObjectPool.java
URL: http://svn.apache.org/viewvc/commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericObjectPool.java?rev=1509322&r1=1509321&r2=1509322&view=diff
==============================================================================
--- commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPool.java (original)
+++ commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPool.java Thu Aug  1 16:38:13 2013
@@ -37,6 +37,7 @@ import org.apache.commons.pool2.KeyedPoo
 import org.apache.commons.pool2.PoolUtils;
 import org.apache.commons.pool2.PooledObject;
 import org.apache.commons.pool2.PooledObjectState;
+import org.apache.commons.pool2.SwallowedExceptionListener;
 
 /**
  * A configurable <code>KeyedObjectPool</code> implementation.
@@ -447,7 +448,7 @@ public class GenericKeyedObjectPool<K,T>
      * destroyed.
      * <p>
      * Exceptions encountered destroying objects for any reason are swallowed
-     * but remain accessible via {@link #getSwallowedExceptions()}.
+     * but notified via a {@link SwallowedExceptionListener}.
      *
      * @param key pool key
      * @param obj instance to return to the keyed pool
@@ -572,8 +573,8 @@ public class GenericKeyedObjectPool<K,T>
      * <li>Invoking this method does not prevent objects being returned to the
      * idle instance pool, even during its execution. Additional instances may
      * be returned while removed items are being destroyed.</li>
      * <li>Exceptions encountered destroying idle instances are swallowed but
      * remain accessible via {@link #getSwallowedExceptions()}.</li>
      * </ul>
      */
     @Override
@@ -589,8 +590,8 @@ public class GenericKeyedObjectPool<K,T>
     /**
      * Clears the specified sub-pool, removing all pooled instances
      * corresponding to the given <code>key</code>. Exceptions encountered
      * destroying idle instances are swallowed but remain accessible via
      * {@link #getSwallowedExceptions()}.
      *
      * @param key the key to clear
      */
@@ -572,8 +573,8 @@ public class GenericKeyedObjectPool<K,T>
      * idle instance pool, even during its execution. Additional instances may
      * be returned while removed items are being destroyed.</li>
-     * <li>Exceptions encountered destroying idle instances are swallowed but
-     * remain accessible via {@link #getSwallowedExceptions()}.</li>
+     * <li>Exceptions encountered destroying idle instances are swallowed
+     * but notified via a {@link SwallowedExceptionListener}.</li>
      * </ul>
      */
@@ -589,8 +590,8 @@ public class GenericKeyedObjectPool<K,T>
      * Clears the specified sub-pool, removing all pooled instances
      * corresponding to the given <code>key</code>. Exceptions encountered
-     * destroying idle instances are swallowed but remain accessible via
-     * {@link #getSwallowedExceptions()}.
+     * destroying idle instances are swallowed but notified via a
+     * {@link SwallowedExceptionListener}.
      *
      * @param key the key to clear

Modified: commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPoolMXBean.java
URL: http://svn.apache.org/viewvc/commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericKeyedObjectPoolMXBean.java?rev=1509322&r1=1509321&r2=1509322&view=diff
==============================================================================
--- commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericObjectPool.java (original)
+++ commons/proper/pool/trunk/src/main/java/org/apache/commons/pool2/impl/GenericObjectPool.java Thu Aug  1 16:38:13 2013
@@ -31,6 +31,7 @@ import org.apache.commons.pool2.PoolUtil
 import org.apache.commons.pool2.PooledObject;
 import org.apache.commons.pool2.PooledObjectFactory;
 import org.apache.commons.pool2.PooledObjectState;
+import org.apache.commons.pool2.SwallowedExceptionListener;
 import org.apache.commons.pool2.TrackedUse;
 
 /**
@@ -495,7 +496,7 @@ public class GenericObjectPool<T> extend
      * this case, if validation fails, the instance is destroyed.
      * <p>
      * Exceptions encountered destroying objects for any reason are swallowed
-     * but remain accessible via {@link #getSwallowedExceptions()}.
+     * but notified via a {@link SwallowedExceptionListener}..
      *
      * @param obj instance to return to the pool
      */
@@ -615,8 +616,8 @@ public class GenericObjectPool<T> extend
      * <li>Invoking this method does not prevent objects being returned to the
      * idle instance pool, even during its execution. Additional instances may
      * be returned while removed items are being destroyed.</li>
      * <li>Exceptions encountered destroying idle instances are swallowed but
      * remain accessible via {@link #getSwallowedExceptions()}.</li>
      * </ul>
      */
     @Override
@@ -615,8 +616,8 @@ public class GenericObjectPool<T> extend
      * idle instance pool, even during its execution. Additional instances may
      * be returned while removed items are being destroyed.</li>
-     * <li>Exceptions encountered destroying idle instances are swallowed but
-     * remain accessible via {@link #getSwallowedExceptions()}.</li>
+     * <li>Exceptions encountered destroying idle instances are swallowed
+     * but notified via a {@link SwallowedExceptionListener}.</li>
      * </ul>
      */